"""About this package."""

__all__ = [
    "__title__",
    "__summary__",
    "__uri__",
    "__version__",
    "__author__",
    "__email__",
    "__license__",
    "__copyright__",
]

__title__ = "argo-workflows"
__summary__ = "Client for Argo Workflows"
__uri__ = "https://github.com/CermakM/argo-client-python"

__version__ = "3.0.2"

__author__ = "Marek Cermak"
__email__ = "macermak@redhat.com"

__license__ = "MIT"
__copyright__ = "Copyright 2019 {0}".format(__author__)
