from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from argo.workflows.client.api.archived_workflow_service_api import ArchivedWorkflowServiceApi
from argo.workflows.client.api.cron_workflow_service_api import CronWorkflowServiceApi
from argo.workflows.client.api.info_service_api import InfoServiceApi
from argo.workflows.client.api.workflow_service_api import WorkflowServiceApi
from argo.workflows.client.api.workflow_template_service_api import WorkflowTemplateServiceApi
from argo.workflows.client.api.v1alpha1_api import V1alpha1Api
